from handler import handler
import resourcer
from random import *
import pygame
import config
import math
from animated_sprite import animated_sprite
from utils import *
import movements

_exists_golden = False

class enemy:
	def __init__(self, sprite, position, parametrized, frequency, color):
		'''Parameters:
			* sprite: a animated_sprite with the information about the graphics.
			* position: the 'zero' position of the trayectory.
			* parametrized: f: [0, 1] -> (x, y) position of the enemy
			* frequency: make the enemy move faster or slower
			* color: which color the enemy is.
				'red', 'blue', 'green', or 'black'
		'''
		self.image = sprite
		self.pos = position
		self.param = parametrized
		self.freq = frequency
		self.color = color
		self.elapsed = 0
	
	def get_pos(self):
		dr = self.param(math.sin(float(self.elapsed)*math.pi/self.freq))
		return (self.pos[0] + dr[0], self.pos[1] + dr[1])
	
	def draw(self, surface):
		surface.blit(self.image.image, self.get_pos())
		if self.elapsed < config.PLOP_TIME:
			surface.blit(resourcer.load('img/create%d.png'%
				(1+5*self.elapsed/config.PLOP_TIME)), self.get_pos())
	
	def timer(self, ticks):
		self.elapsed += ticks
		self.image.update(ticks)

class golden_enemy(enemy):
	def __init__(self):
		_exists_golden = True
		#sound_golden = resourcer.load('sound/golden.ogg')
		#sound_golden.play()
		enemy.__init__(self, animated_sprite(get_golden_enemy()[0]),
			(470, 100),
			movements.golden_movement,
			3000,
			'golden'
		)
		self.timeout = 10000
	
	def timer(self, ticks):
		enemy.timer(self, ticks)
		self.timeout -= ticks

class enemy_handler(handler):
	def __init__(self, posible_positions):
		self.list_of_enemies = []
		self.posible_positions = posible_positions
		
		self.generate_images = []
		for i in range(1,6):
			self.generate_images.append(resourcer.load('img/create' + str(i) + '.png'))
		self.create = animated_sprite(self.generate_images)
		
	
	def generate_enemy(self):
		if _exists_golden == False and random.random() < config.RANDOM_GOLDEN:
			new_enemy = golden_enemy()
		else:
			data = get_random_enemy()
			new_enemy = enemy(
				animated_sprite(data[0]),
				(randrange(10, config.WIDTH-100),
				randint(self.posible_positions[0], self.posible_positions[1])),
				choice([
					movements.linear(randint(30, 200)),
					movements.jumper(randint(30, 100)),
					movements.fuzzy(20, 0, 0.1),
					movements.circular(40),
				]),
				randint(1000, 3000),
				data[1]
			)
		self.list_of_enemies.append(new_enemy)
	
	def check_collition(self, pos):	
		ret_list = []
		for john in self.list_of_enemies:
			if contained_in_alpha(pos, john.image, john.get_pos()):
				ret_list.append({'color': john.color, 'position': john.get_pos()})
				self.list_of_enemies.remove(john)
				if john.__class__ == golden_enemy:
					_exists_golden = False
		return ret_list
	
	def draw(self, surface):
		#surface.blit(self.create.image, (200,200))
		for john in self.list_of_enemies:
			john.draw(surface)
	
	def timer(self, ticks):
		for john in self.list_of_enemies:
			john.timer(ticks)
			if john.__class__ == golden_enemy:
				if john.timeout < 0:
					self.list_of_enemies.remove(john)
					_exists_golden = False
		while len(self.list_of_enemies) < config.ENEMIES_PER_ROUND:
			self.generate_enemy()
	
	def events(self,events):
		for event in events:
			if event.type == pygame.KEYDOWN:
				if config.DEBUG and event.key == pygame.K_g:
					self.generate_enemy()
