import config
import math
import resourcer
import pygame

class handler:
	def __init__(self):
		pass
	
	def timer(self, ticks):
		pass
	
	def draw(self, surface):
		pass
	
	def events(self, events):
		pass

class game_background_handler(handler):
	def __init__(self):
		self.img_day = resourcer.load('img/bg/daylight.png')
		self.img_night = resourcer.load('img/bg/night.png')
		self.img_buildings = resourcer.load('img/bg/buildings.png')
		self.img_sun = resourcer.load('img/bg/sun.png')
		self.img_moon = resourcer.load('img/bg/moon.png')
		self.img_river = resourcer.load('img/bg/river.png')
		self.img_floor = resourcer.load('img/bg/floor.png')
		self.sf_night = pygame.Surface(self.img_night.get_size())
		self.sf_night.blit(self.img_night, (0,0))
		self.phi = 0.0
	
	def timer(self, ticks):
		self.phi += float(ticks)/4000.0
		if 0 < math.sin(self.phi) < 0.5:
			self.sf_night.set_alpha(math.sin(self.phi)*512)
	
	def draw(self, surface):
		surface.blit(self.img_day, (0,0))
		surface.blit(self.sf_night, (0,0))
		surface.blit(self.img_sun,
			(math.cos(self.phi)*500+500, math.sin(self.phi)*500+500))
		surface.blit(self.img_moon, 
			(-math.cos(self.phi)*500+500, -math.sin(self.phi)*500+500))
		surface.blit(self.img_buildings, (0,150))
		surface.blit(self.img_river, (0, 320))
		surface.blit(self.img_floor, (0, 360))

class hud_handler(handler):
	'''
	HUD Handler
	
	Also handles score for the player.
	Also handles keyboard events to quit.
	
	The score goes like this:
		- Successful hit: +1 * multiplier
		- Unsuccesful hit: -1; multiplier = 1
	
	The status bar is ruled by these rules:
		- Starting status: 0
		- Each second passing, -1 status
		- Hitting the wrong color: -2 status
		- Each point gained, +3 status
	'''
	def __init__(self):
		self.img_hud = resourcer.load('img/hud.png')
		self.img_guide = resourcer.load('img/guide.png')
		self.img_glow = resourcer.load('img/glow.png')
		self.font1 = pygame.font.Font('font/LithosPro-Black.otf', 25)
		self.font2 = pygame.font.Font('font/LithosPro-Regular.otf', 38)
		self.score = 0
		self.multiplier = 1
		self.stroke = 0
		self.statusbar = 0
		self.acumm = 0
		self.total = 0
		self.sound_miss = resourcer.load('sound/missshot.ogg')
		#self.sound_shot = resourcer.load('sound/shot.ogg')
		self.sound_hit = resourcer.load('sound/shot.ogg')
	
	def draw(self, surface):
		surface.blit(self.img_hud, (0,config.HEIGHT-self.img_hud.get_height()))
		surface.blit(self.img_guide, (334-((self.statusbar+100)*284)/200, 638))
		score = self.font1.render(str(self.score), True, resourcer.color['black'])
		mult = self.font2.render(str(self.multiplier), True, resourcer.color['white'])
		surface.blit(score, (777-score.get_width(), 651))
		surface.blit(mult, (750-mult.get_width(), 700))
		if self.statusbar < -86:
			surface.blit(self.img_glow, (327, 625)) 
		if self.statusbar > 86:
			surface.blit(self.img_glow, (3, 625))
	
	def timer(self, ticks):
		self.total += ticks
		self.acumm += ticks
		if self.acumm >= 2000:
			self.statusbar -= self.total*1*self.acumm/20000000
			self.acumm %= 2000
	
	def process_shot(self, shots, bullet_color):
		hits = 0
		#self.sound_shot.play() #sonido de que disparo
		for shot in shots:
			if bullet_color == 'golden' or shot['color'] == 'golden' or shot['color'] == bullet_color:
				hits += 1
		
		if hits:
			self.sound_hit.play() #sonido de que le pego
			self.stroke += hits
			if self.stroke == config.STROKES_TO_MULTIPLY:
				self.multiplier += 1
				self.stroke = 0
			self.score += 100*hits*self.multiplier
			self.statusbar += hits*3*self.multiplier
		else:
			self.sound_miss.play() #sonido de que le erro
			self.statusbar -= 2*len(shots)
			self.multiplier = 1
			self.score -= 30*len(shots)
			self.stroke = 0
	
	def events(self, events):
		for event in events:
			if event.type == pygame.KEYDOWN:
				if event.key == pygame.K_ESCAPE:
					return "exit_signal"
				if event.key == pygame.K_q:
					return "exit_signal"
				if config.DEBUG and event.key == pygame.K_z:
					self.statusbar -= 10
				if config.DEBUG and event.key == pygame.K_a:
					self.statusbar += 10
				if event.key == pygame.K_SPACE:
					return "pause_signal"
			if event.type == pygame.QUIT:
				return "exit_signal"
		if config.DEBUG:
			print self.statusbar
		if self.statusbar < -100:
			return "color_wins"
		if self.statusbar > 100:
			return "black_wins"
				