from scene import scene
import pygame
import resourcer
import config
import highscores

class tutorial(scene):
	def __init__(self, callback, surface):
		self.surfaces = [
			resourcer.load('img/tutorial/Golden.png'),
			resourcer.load('img/tutorial/Reload.png'),
			resourcer.load('img/tutorial/Barra.png'),
			resourcer.load('img/tutorial/Mal.png'),
			resourcer.load('img/tutorial/Bien.png'),
		]
		scene.__init__(self, callback, surface)
	
	def mouse_click(self, pos):
		self.surfaces.pop()
		if len(self.surfaces) == 0:
			self.callback()
	
	def key_pressed(self, keycode):
		self.surfaces.pop()
		if len(self.surfaces) == 0:
			self.callback()

class presentation(scene):
	def __init__(self, callback, surface):
		self.surfaces = [
			resourcer.load('img/logoopcional.png')
		]
		self.timeout = 3000
		self.timer = pygame.time.Clock()
		scene.__init__(self, callback, surface)
	def loop(self):
		self.timeout -= self.timer.tick()
		if self.timeout < 0:
			self.callback()
		scene.loop(self)

class new_game(scene):
	def __init__(self, callback, surface):
		self.surfaces = [
			resourcer.load('img/intro.png'),
		]
		#self.sound_intro = resourcer.load('sound/intro.ogg')
		#self.sound_intro.play()
		
		pygame.mixer.music.load('sound/intro.ogg')
		pygame.mixer.music.play(-1)
		scene.__init__(self, callback, surface)

	def mouse_click(self, pos):
		self.callback()
	
	def key_pressed(self, keycode):
		self.callback()

class high_scores(scene):
	def __init__(self, callback, surface):
		texto = pygame.Surface((config.WIDTH, config.HEIGHT), pygame.SRCALPHA)
		valores = highscores.Load()
		the_font = pygame.font.Font('font/LithosPro-Black.otf', 20)
		altura = 200
				
		for val in valores:
			points = the_font.render(str(val[0]), True, resourcer.color['white'])
			name = the_font.render(val[1], True, resourcer.color['white'])
			texto.blit(points, (config.WIDTH - 50 - points.get_width(), altura))
			texto.blit(name, (50, altura))
			altura += name.get_height()+30
		
		self.surfaces = [
			resourcer.load('img/highscores.png'),
			texto,
		]
		scene.__init__(self, callback, surface)
	
	def mouse_click(self, pos):
		self.callback()
	
	def key_pressed(self, keycode):
		self.callback()

class pause(scene):
	def __init__(self, callback, surface, screenshot):
		gray = pygame.Surface((config.WIDTH, config.HEIGHT))
		gray.fill(resourcer.color['black'])
		gray.set_alpha(150)
		self.surfaces = [
			screenshot,
			gray,
		]
		#sonido de pausa?
		scene.__init__(self, callback, surface)
		

class black_wins(scene):
	def __init__(self, callback, surface):
		self.surfaces = [
			resourcer.load('img/final2.png'),
		]
		#self.music = resourcer.load('sound/black_wins.ogg')
		#self.music.play()
		scene.__init__(self, callback, surface)
		

class color_wins(scene):
	def __init__(self, callback, surface):
		self.surfaces = [
			resourcer.load('img/final1.png'),
		]
		#self.music = resourcer.load('sound/color_wins.ogg')
		#self.music.play()

		scene.__init__(self, callback, surface)
		
class new_highscore(scene):
	def __init__(self, callback, surface, score):
		self.name = ""
		self.score = score
		self.font = pygame.font.Font('font/LithosPro-Black.otf', 40)
		self.surfaces = [
			resourcer.load('img/new_highscore.png'),
			pygame.Surface(surface.get_size(), pygame.SRCALPHA),
		]
		self.redraw_font()
		scene.__init__(self, callback, surface)
	
	def redraw_font(self):
		new_font = self.font.render(self.name, True, resourcer.color['white'])
		self.surfaces[1].fill(resourcer.color['transparent'])
		#Draw the username:
		self.surfaces[1].blit(new_font, ((config.WIDTH-new_font.get_width())/2,
			560))
		# Draw the type slash:
		pygame.draw.line(self.surfaces[1], resourcer.color['white'],
			((config.WIDTH+new_font.get_width())/2+5, 560),
			((config.WIDTH+new_font.get_width())/2+5, 590), 3)
	
	def key_pressed(self, keycode):
		if keycode == pygame.K_RETURN:
			highscores.Save(self.name, self.score)
			self.callback()
		if keycode == pygame.K_ESCAPE:
			self.callback()
		if keycode == pygame.K_BACKSPACE:
			self.name = self.name[:-1]
			self.redraw_font()
		if pygame.K_a <= keycode <= pygame.K_z:
			if len(self.name) < 30: #si no es muy largo
				if (pygame.key.get_mods() & (pygame.KMOD_SHIFT | pygame.KMOD_CAPS)):
					self.name += chr(keycode - 32)
				else:
					self.name += chr(keycode)
			self.redraw_font()
		if keycode == pygame.K_SPACE and (len(self.name) < 30):
			self.name += ' '
			self.redraw_font()